<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=ast
// ** ne pas modifier le fichier **

return [

	// E
	'explication_url_statique_ressources' => 'Una URL que permite sirvir los ficheros estáticos (imáxenes, JS…) ensin cookie. Polo xeneral, un sub-dominiu alternativu que tamién apunta al sitiu.',

	// I
	'info_compresseur_titre' => 'Igües y compresión',
	'info_question_activer_compactage_css' => 'CSS',
	'info_question_activer_compactage_js' => 'Scripts',
	'item_compresseur_css' => 'Activar la comprensión de les fueyes d’estilu (CSS)',
	'item_compresseur_js' => 'Activar la compresión de los scripts (javascript)',

	// L
	'label_url_statique_ressources' => 'Recursos URL',

	// T
	'texte_compacter_avertissement' => 'Cuida de nun activar estes opciones mientres se desendolca’l sitiu: los elementos compautaos pierden la visibilidá.',
	'texte_compacter_script_css' => 'SPIP pue compautar los scripts JavaScript y les fueyes d’estilu CSS, pa guardalos como archivos estáticos; esto acelera l’amosamientu del sitiu.',
	'titre_compacter_script_css' => 'Compautación de los scripts y CSS',
];
